<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CmdMeshPartCrossSections</name>
    <message>
        <location filename="../../Command.cpp" line="269"/>
        <source>MeshPart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="270"/>
        <source>Cross-sections...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="271"/>
        <source>Cross-sections</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
        <location filename="../../Command.cpp" line="305"/>
        <source>Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="306"/>
        <source>Curve on mesh...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="307"/>
        <source>Creates an approximated curve on top of a mesh.
This command only works with a &apos;mesh&apos; object.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdMeshPartMesher</name>
    <message>
        <location filename="../../Command.cpp" line="58"/>
        <source>Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="59"/>
        <source>Create mesh from shape...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="60"/>
        <source>Tessellate shape</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdMeshPartSection</name>
    <message>
        <location filename="../../Command.cpp" line="185"/>
        <source>Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="186"/>
        <source>Create section from mesh and plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="187"/>
        <source>Section</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
        <location filename="../../Command.cpp" line="83"/>
        <source>Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="84"/>
        <source>Trim mesh with a plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="85"/>
        <location filename="../../Command.cpp" line="86"/>
        <source>Trims a mesh with a plane</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message>
        <location filename="../../Command.cpp" line="129"/>
        <source>Trim with plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="208"/>
        <source>Section with plane</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPartGui::CrossSections</name>
    <message>
        <location filename="../../CrossSections.ui" line="14"/>
        <source>Cross sections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="20"/>
        <source>Guiding plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="26"/>
        <source>XY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="36"/>
        <source>XZ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="43"/>
        <source>YZ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="52"/>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="71"/>
        <source>Sections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="83"/>
        <source>On both sides</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="92"/>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="109"/>
        <source>Distance:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="128"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.ui" line="134"/>
        <source>Connect edges if distance less than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CrossSections.cpp" line="366"/>
        <source>Failure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="364"/>
        <source>Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="366"/>
        <source>Close wire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="368"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="369"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="615"/>
        <source>Wrong mesh picked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CurveOnMesh.cpp" line="655"/>
        <source>No point was picked</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="14"/>
        <source>Curve on mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="23"/>
        <source>Press &apos;Start&apos;, then pick points on the mesh; when enough points have been set, right-click and choose &apos;Create&apos;. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a &apos;mesh&apos; object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="38"/>
        <source>Wire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="44"/>
        <source>Snap tolerance to vertices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="51"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="61"/>
        <source>Split threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="87"/>
        <source>Spline Approximation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="96"/>
        <source>Tolerance to mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="122"/>
        <source>Continuity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="136"/>
        <source>Maximum curve degree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TaskCurveOnMesh.ui" line="153"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPartGui::Tessellation</name>
    <message>
        <location filename="../../Tessellation.ui" line="14"/>
        <source>Tessellation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="20"/>
        <source>Meshing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="30"/>
        <source>Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="33"/>
        <source>Use the standard mesher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="41"/>
        <source>Surface deviation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="48"/>
        <source>Maximal linear deflection of a mesh section from the surface of the object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="67"/>
        <source>Angular deviation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="74"/>
        <source>Maximal angular deflection of a mesh section to the next section</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="98"/>
        <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="102"/>
        <source>Relative surface deviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="109"/>
        <source>Mesh will get face colors of the object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="112"/>
        <source>Apply face colors to mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="119"/>
        <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="124"/>
        <source>Define segments by face colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="145"/>
        <source>Mefisto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="148"/>
        <source>Use the Mefisto mesher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="156"/>
        <source>Maximum edge length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="162"/>
        <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="183"/>
        <source>Estimate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="206"/>
        <source>Netgen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="209"/>
        <source>Use the Netgen mesher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="217"/>
        <source>Fineness:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="234"/>
        <source>Very coarse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="239"/>
        <source>Coarse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="244"/>
        <source>Moderate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="249"/>
        <source>Fine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="254"/>
        <source>Very fine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="259"/>
        <source>User defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="269"/>
        <source>Mesh size grading:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="279"/>
        <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="302"/>
        <source>Elements per edge:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="312"/>
        <location filename="../../Tessellation.ui" line="345"/>
        <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="335"/>
        <source>Elements per curvature radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="370"/>
        <source>Whether optimization of surface shape will be done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="373"/>
        <source>Optimize surface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="383"/>
        <source>Whether second order elements will be generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="386"/>
        <source>Second order elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="393"/>
        <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="396"/>
        <source>Quad dominated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.ui" line="422"/>
        <source>Leave panel open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.cpp" line="61"/>
        <source>Gmsh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.cpp" line="225"/>
        <location filename="../../Tessellation.cpp" line="231"/>
        <source>No active document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.cpp" line="259"/>
        <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.cpp" line="263"/>
        <source>You have selected a shape without faces.
Select a different shape, please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Tessellation.cpp" line="267"/>
        <source>Select a shape for meshing, first.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPart_Section</name>
    <message>
        <location filename="../../Command.cpp" line="198"/>
        <source>Select plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="199"/>
        <source>Please select a plane at which you section the mesh.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPart_TrimByPlane</name>
    <message>
        <location filename="../../Command.cpp" line="95"/>
        <source>Select plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="96"/>
        <source>Please select a plane at which you trim the mesh.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="102"/>
        <source>Trim by plane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="103"/>
        <source>Select the side you want to keep.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="104"/>
        <source>Below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="105"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Command.cpp" line="106"/>
        <source>Split</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="../../Workbench.cpp" line="36"/>
        <source>MeshPart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
        <location filename="../../MeshFlatteningCommand.py" line="47"/>
        <source>Unwrap Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MeshFlatteningCommand.py" line="50"/>
        <source>Find a flat representation of a mesh.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
        <location filename="../../MeshFlatteningCommand.py" line="79"/>
        <source>Unwrap Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MeshFlatteningCommand.py" line="82"/>
        <source>Find a flat representation of a face.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
